@@ -11,7 +11,7 @@ from pydantic import BaseModel, Field, HttpUrl, conlist
 # from hashlib import blake2b
 import orjson
 from .utils import orjson_dumps
-from . import geometry
+from .geometry import geometry
 
 ##############################################3
 ### Base models
@@ -39,7 +39,7 @@ class Station(BaseModel):
     ref: str = Field(None, description='station reference ID given by owner')
     name: str = None
     osm_id: int = None
-    geometry: Union[geometry.Point, geometry.LineString, geometry.Polygon, geometry.MultiLineString, geometry.MultiPoint, geometry.MultiPolygon]
+    geometry: geometry
     altitude: float = None
     # heights: List[int]
     properties: Dict = Field(None, description='Any additional station specific properties.')
