@@ -110,7 +110,7 @@ class Dataset(DatasetBase):
     spatial_distribution: str = Field(..., description='This describes how the spatial data are distributed. Either sparse or grid.')
     geometry_type: str = Field(..., description='This describes how the spatial dimensions are stored. Point, Line, Polygon, or Collection. Follows the OGC spatial data types.')
     grouping: str = Field(..., description='This describes how the staions and the associated data are grouped. Either none or blocks.')
-    extent: base.Geometry = Field(None, description='The geographical extent of the datset as a simple rectangular polygon.')
+    extent: geometry = Field(None, description='The geographical extent of the datset as a simple rectangular polygon.')
     time_range: TimeRange = Field(None, description='The maximum time range of the dataset.')
     spatial_resolution: float = Field(None, description='The spatial resolution in decimal degrees if the spatial_distribution is grid.')
     heights: List[int] = Field(None, description='The heights from all available results in the dataset.')
